#ifndef URDF_JOINT_TYPES_H
#define URDF_JOINT_TYPES_H


enum UrdfJointTypes
{
		URDFRevoluteJoint=1,
		URDFPrismaticJoint,
		URDFContinuousJoint,
		URDFFloatingJoint,
		URDFPlanarJoint,
		URDFFixedJoint,
};


#endif //URDF_JOINT_TYPES_H
